
## Stats on typeshed's stubs for `beautifulsoup4`

### Number of lines
840

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `beautifulsoup4`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 242
    - Unannotated parameters: 139
    - Explicit `Any` parameters: 32
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 193
    - Unannotated returns: 49
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 182
    - Explicit `Any` variables: 71
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `python-nmap`

### Number of lines
131

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-nmap`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 44
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 44
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 30
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `Flask-SQLAlchemy`

### Number of lines
125

### Package status: *obsolete*
Upstream has added type hints; these typeshed stubs are now obsolete.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Flask-SQLAlchemy`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 54
    - Unannotated parameters: 24
    - Explicit `Any` parameters: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 5
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 19
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pynput`

### Number of lines
297

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pynput`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 81
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 71
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 102
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pyvmomi`

### Number of lines
221

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyvmomi`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 50
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 16
- Variables:
    - Annotated variables: 57
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `entrypoints`

### Number of lines
53

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `entrypoints`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 23
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `simplejson`

### Number of lines
59

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `simplejson`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 36
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 18
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `six`

### Number of lines
369

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `six`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 67
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `tqdm`

### Number of lines
1444

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tqdm`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 789
    - Unannotated parameters: 129
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 18
- Returns:
    - Annotated returns: 139
    - Unannotated returns: 24
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 97
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 70

<hr>

## Stats on typeshed's stubs for `html5lib`

### Number of lines
745

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `html5lib`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 65
    - Unannotated parameters: 209
    - Explicit `Any` parameters: 27
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 99
    - Unannotated returns: 209
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 220
    - Explicit `Any` variables: 180
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `typed-ast`

### Number of lines
730

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `typed-ast`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 29
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 313
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `google-cloud-ndb`

### Number of lines
1572

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `google-cloud-ndb`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 480
    - Unannotated parameters: 383
    - Explicit `Any` parameters: 134
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 234
    - Unannotated returns: 203
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 191
    - Explicit `Any` variables: 139
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `flake8-bugbear`

### Number of lines
29

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-bugbear`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 8
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pyflakes`

### Number of lines
514

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyflakes`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 269
    - Unannotated parameters: 69
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 211
    - Unannotated returns: 2
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 108
    - Explicit `Any` variables: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `opentracing`

### Number of lines
369

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `opentracing`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 105
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 22
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 56
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `editdistance`

### Number of lines
9

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `editdistance`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Stats on typeshed's stubs for `pyaudio`

### Number of lines
191

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyaudio`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 53
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 90
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pytz`

### Number of lines
151

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pytz`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 69
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 51
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 27
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Stats on typeshed's stubs for `psutil`

### Number of lines
1677

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `psutil`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 117
    - Unannotated parameters: 310
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 185
    - Unannotated returns: 358
    - Explicit `Any` returns: 47
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 586
    - Explicit `Any` variables: 206
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 71

<hr>

## Stats on typeshed's stubs for `invoke`

### Number of lines
810

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `invoke`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 242
    - Unannotated parameters: 174
    - Explicit `Any` parameters: 28
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 177
    - Unannotated returns: 73
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 130
    - Explicit `Any` variables: 70
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `aws-xray-sdk`

### Number of lines
801

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `aws-xray-sdk`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 125
    - Unannotated parameters: 168
    - Explicit `Any` parameters: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 180
    - Unannotated returns: 94
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 141
    - Explicit `Any` variables: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pytest-lazy-fixture`

### Number of lines
16

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pytest-lazy-fixture`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 7
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `requests`

### Number of lines
1034

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `requests`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 349
    - Unannotated parameters: 157
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 111
    - Unannotated returns: 86
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 139
    - Explicit `Any` variables: 43
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `PyAutoGUI`

### Number of lines
235

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyAutoGUI`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 145
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 23
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pywin32`

### Number of lines
35221

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pywin32`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3366
    - Unannotated parameters: 3815
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 388
- Returns:
    - Annotated returns: 3772
    - Unannotated returns: 2072
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 296
- Variables:
    - Annotated variables: 24951
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2813

<hr>

## Stats on typeshed's stubs for `Pillow`

### Number of lines
2742

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Pillow`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 625
    - Unannotated parameters: 625
    - Explicit `Any` parameters: 64
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 456
    - Unannotated returns: 347
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 800
    - Explicit `Any` variables: 335
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `redis`

### Number of lines
5536

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `redis`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3392
    - Unannotated parameters: 1331
    - Explicit `Any` parameters: 348
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 88
- Returns:
    - Annotated returns: 1265
    - Unannotated returns: 657
    - Explicit `Any` returns: 317
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 630
    - Explicit `Any` variables: 235
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 12

<hr>

## Stats on typeshed's stubs for `whatthepatch`

### Number of lines
109

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `whatthepatch`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 31
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 50
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `fpdf2`

### Number of lines
1917

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `fpdf2`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 472
    - Unannotated parameters: 603
    - Explicit `Any` parameters: 24
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 44
- Returns:
    - Annotated returns: 284
    - Unannotated returns: 247
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 521
    - Explicit `Any` variables: 76
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 41

<hr>

## Stats on typeshed's stubs for `caldav`

### Number of lines
572

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `caldav`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 199
    - Unannotated parameters: 29
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 109
    - Unannotated returns: 7
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 94
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `python-slugify`

### Number of lines
30

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-slugify`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 19
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `D3DShot`

### Number of lines
657

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *skipped*
Stubtest is skipped in CI for this package.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `D3DShot`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 127
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 255
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 107
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pysftp`

### Number of lines
173

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pysftp`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 109
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `prettytable`

### Number of lines
305

### Package status: *obsolete*
Upstream has added type hints; these typeshed stubs are now obsolete.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `prettytable`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 18
    - Unannotated parameters: 78
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 56
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `zxcvbn`

### Number of lines
202

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `zxcvbn`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 63
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 77
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `flake8-docstrings`

### Number of lines
21

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-docstrings`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `regex`

### Number of lines
736

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `regex`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 424
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 104
    - Unannotated returns: 0
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 70
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `PyScreeze`

### Number of lines
196

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyScreeze`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 93
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 15
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `flake8-typing-imports`

### Number of lines
17

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-typing-imports`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `braintree`

### Number of lines
3136

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `braintree`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 80
    - Unannotated parameters: 394
    - Explicit `Any` parameters: 74
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 304
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1301
    - Explicit `Any` variables: 432
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `paho-mqtt`

### Number of lines
528

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `paho-mqtt`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 217
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 147
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 163
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pycurl`

### Number of lines
647

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pycurl`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 19
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 26
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 601
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `termcolor`

### Number of lines
14

### Package status: *obsolete*
Upstream has added type hints; these typeshed stubs are now obsolete.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `termcolor`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 9
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `psycopg2`

### Number of lines
1655

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `psycopg2`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 171
    - Unannotated parameters: 329
    - Explicit `Any` parameters: 56
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 189
    - Unannotated returns: 169
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 534
    - Explicit `Any` variables: 168
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `commonmark`

### Number of lines
401

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `commonmark`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 63
    - Unannotated parameters: 158
    - Explicit `Any` parameters: 55
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 84
    - Unannotated returns: 76
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 133
    - Explicit `Any` variables: 86
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `cffi`

### Number of lines
921

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `cffi`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 295
    - Unannotated parameters: 251
    - Explicit `Any` parameters: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 20
- Returns:
    - Annotated returns: 191
    - Unannotated returns: 132
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 261
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 115

<hr>

## Stats on typeshed's stubs for `click-spinner`

### Number of lines
37

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `click-spinner`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 11
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `colorama`

### Number of lines
217

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `colorama`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 89
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 87
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `decorator`

### Number of lines
71

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `decorator`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 36
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `cryptography`

### Number of lines
1986

### Package status: *obsolete*
Upstream has added type hints; these typeshed stubs are now obsolete.

### Stubtest settings in CI: *skipped*
Stubtest is skipped in CI for this package.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `cryptography`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 615
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 552
    - Unannotated returns: 14
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 279
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `parsimonious`

### Number of lines
217

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `parsimonious`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 114
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 36
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `tabulate`

### Number of lines
57

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tabulate`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 27
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `dj-database-url`

### Number of lines
27

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `dj-database-url`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 9
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `python-jose`

### Number of lines
399

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-jose`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 86
    - Unannotated parameters: 39
    - Explicit `Any` parameters: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 30
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 118
    - Explicit `Any` variables: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `toml`

### Number of lines
154

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `toml`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 15
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `urllib3`

### Number of lines
808

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `urllib3`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 158
    - Unannotated parameters: 161
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 95
    - Unannotated returns: 61
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 160
    - Explicit `Any` variables: 54
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `chevron`

### Number of lines
46

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `chevron`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 29
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `openpyxl`

### Number of lines
9721

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `openpyxl`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2594
    - Unannotated parameters: 667
    - Explicit `Any` parameters: 2218
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 744
    - Unannotated returns: 423
    - Explicit `Any` returns: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4197
    - Explicit `Any` variables: 3566
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `httplib2`

### Number of lines
280

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `httplib2`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 122
    - Explicit `Any` parameters: 37
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 25
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 85
    - Explicit `Any` variables: 57
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `backports.ssl_match_hostname`

### Number of lines
9

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `backports.ssl_match_hostname`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `xmltodict`

### Number of lines
38

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `xmltodict`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 20
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `PyYAML`

### Number of lines
1285

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyYAML`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 389
    - Unannotated parameters: 322
    - Explicit `Any` parameters: 52
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 158
    - Unannotated returns: 230
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 225
    - Explicit `Any` variables: 192
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `passlib`

### Number of lines
1947

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `passlib`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 377
    - Unannotated parameters: 473
    - Explicit `Any` parameters: 174
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 155
    - Unannotated returns: 329
    - Explicit `Any` returns: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 570
    - Explicit `Any` variables: 105
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `xxhash`

### Number of lines
53

### Package status: *obsolete*
Upstream has added type hints; these typeshed stubs are now obsolete.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `xxhash`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 26
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Stats on typeshed's stubs for `vobject`

### Number of lines
596

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `vobject`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 95
    - Unannotated parameters: 185
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 72
    - Unannotated returns: 104
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 184
    - Explicit `Any` variables: 93
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `Send2Trash`

### Number of lines
27

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Send2Trash`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `croniter`

### Number of lines
95

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `croniter`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 35
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `ttkthemes`

### Number of lines
84

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `ttkthemes`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 14
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 10
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pyRFC3339`

### Number of lines
18

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyRFC3339`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 14
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 8
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `python-crontab`

### Number of lines
293

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-crontab`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 90
    - Unannotated parameters: 44
    - Explicit `Any` parameters: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 18
- Returns:
    - Annotated returns: 80
    - Unannotated returns: 58
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 67
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 32

<hr>

## Stats on typeshed's stubs for `playsound`

### Number of lines
5

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `playsound`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 1
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `mypy-extensions`

### Number of lines
70

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `mypy-extensions`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `bleach`

### Number of lines
195

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `bleach`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 58
    - Unannotated parameters: 17
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 9
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 6
- Variables:
    - Annotated variables: 45
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `setuptools`

### Number of lines
2686

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `setuptools`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 833
    - Unannotated parameters: 395
    - Explicit `Any` parameters: 79
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 665
    - Unannotated returns: 262
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 640
    - Explicit `Any` variables: 401
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 9

<hr>

## Stats on typeshed's stubs for `annoy`

### Number of lines
49

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `annoy`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `boto`

### Number of lines
1958

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `boto`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 835
    - Unannotated parameters: 687
    - Explicit `Any` parameters: 366
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 168
    - Unannotated returns: 442
    - Explicit `Any` returns: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 366
    - Explicit `Any` variables: 267
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `toposort`

### Number of lines
17

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `toposort`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `ujson`

### Number of lines
37

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `ujson`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `flake8-simplify`

### Number of lines
9

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-simplify`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `jsonschema`

### Number of lines
427

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `jsonschema`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 108
    - Unannotated parameters: 295
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 145
    - Unannotated returns: 31
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 62
    - Explicit `Any` variables: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `slumber`

### Number of lines
73

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `slumber`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 23
    - Unannotated parameters: 24
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 23
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `retry`

### Number of lines
29

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `retry`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `aiofiles`

### Number of lines
628

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `aiofiles`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 333
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 21
- Returns:
    - Annotated returns: 133
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `appdirs`

### Number of lines
57

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `appdirs`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 33
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 15
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 8
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `stdlib-list`

### Number of lines
20

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `stdlib-list`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `Markdown`

### Number of lines
791

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Markdown`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 112
    - Unannotated parameters: 145
    - Explicit `Any` parameters: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 112
    - Unannotated returns: 65
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 214
    - Explicit `Any` variables: 83
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `jmespath`

### Number of lines
181

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `jmespath`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 11
    - Unannotated parameters: 123
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 22
    - Unannotated returns: 52
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 41
    - Explicit `Any` variables: 37
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `passpy`

### Number of lines
51

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `passpy`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `flake8-plugin-utils`

### Number of lines
69

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-plugin-utils`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 10
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `oauthlib`

### Number of lines
1481

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `oauthlib`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 271
    - Unannotated parameters: 544
    - Explicit `Any` parameters: 185
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 139
    - Unannotated returns: 211
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 318
    - Explicit `Any` variables: 207
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `stripe`

### Number of lines
1593

### Package status: *out of date*
These stubs are out of date. In CI, stubtest tests these stubs against an older version of this package than the latest that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `stripe`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 261
    - Unannotated parameters: 391
    - Explicit `Any` parameters: 161
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 108
    - Unannotated returns: 168
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 156
    - Explicit `Any` variables: 42
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `PyMySQL`

### Number of lines
1075

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `PyMySQL`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 139
    - Unannotated parameters: 53
    - Explicit `Any` parameters: 38
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 98
    - Unannotated returns: 40
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 734
    - Explicit `Any` variables: 62
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `tree-sitter`

### Number of lines
133

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tree-sitter`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 25
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 52
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `gdb`

### Number of lines
920

### Package status: *not on pypi*
The upstream for this package doesn't exist on PyPI, so whether or not these stubs are up to date or not is unknown.

### Stubtest settings in CI: *skipped*
Stubtest is skipped in CI for this package.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `gdb`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 227
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 247
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 294
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pep8-naming`

### Number of lines
31

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pep8-naming`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 8
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 11
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `docutils`

### Number of lines
606

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `docutils`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 215
    - Unannotated parameters: 60
    - Explicit `Any` parameters: 36
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 148
    - Unannotated returns: 10
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 45
- Variables:
    - Annotated variables: 82
    - Explicit `Any` variables: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `SQLAlchemy`

### Number of lines
16229

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `SQLAlchemy`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2164
    - Unannotated parameters: 7066
    - Explicit `Any` parameters: 1202
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 2153
    - Unannotated returns: 3325
    - Explicit `Any` returns: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3158
    - Explicit `Any` variables: 2065
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `DateTimeRange`

### Number of lines
67

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `DateTimeRange`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 28
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 10
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `peewee`

### Number of lines
1778

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `peewee`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 358
    - Unannotated parameters: 720
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 244
- Returns:
    - Annotated returns: 298
    - Unannotated returns: 448
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 437
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 368

<hr>

## Stats on typeshed's stubs for `console-menu`

### Number of lines
732

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `console-menu`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 210
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 278
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 57
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pyinstaller`

### Number of lines
476

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyinstaller`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 194
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 9
- Returns:
    - Annotated returns: 116
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 103
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `Deprecated`

### Number of lines
65

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Deprecated`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `JACK-Client`

### Number of lines
300

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `JACK-Client`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 107
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 151
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 27
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `certifi`

### Number of lines
2

### Package status: *obsolete*
Upstream has added type hints; these typeshed stubs are now obsolete.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `certifi`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 0
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `cachetools`

### Number of lines
130

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `cachetools`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 86
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 48
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `flake8-rst-docstrings`

### Number of lines
34

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-rst-docstrings`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `tree-sitter-languages`

### Number of lines
11

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tree-sitter-languages`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `contextvars`

### Number of lines
47

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `contextvars`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `flake8-builtins`

### Number of lines
12

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-builtins`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pyfarmhash`

### Number of lines
9

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyfarmhash`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `python-dateutil`

### Number of lines
472

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-dateutil`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 163
    - Unannotated parameters: 64
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 102
    - Unannotated returns: 46
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 95
    - Explicit `Any` variables: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `docopt`

### Number of lines
12

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `docopt`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `hdbcli`

### Number of lines
145

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `hdbcli`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 77
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 6
- Returns:
    - Annotated returns: 62
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 22
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2

<hr>

## Stats on typeshed's stubs for `babel`

### Number of lines
1156

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `babel`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 390
    - Unannotated parameters: 228
    - Explicit `Any` parameters: 52
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 247
    - Unannotated returns: 121
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 250
    - Explicit `Any` variables: 149
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `emoji`

### Number of lines
73

### Package status: *obsolete*
Upstream has added type hints; these typeshed stubs are now obsolete.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `emoji`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 21
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1

<hr>

## Stats on typeshed's stubs for `flake8-2020`

### Number of lines
26

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `flake8-2020`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `Flask-Cors`

### Number of lines
138

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Cors`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 62
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `ldap3`

### Number of lines
2896

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `ldap3`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 527
    - Unannotated parameters: 683
    - Explicit `Any` parameters: 294
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 216
    - Unannotated returns: 423
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 945
    - Explicit `Any` variables: 439
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `paramiko`

### Number of lines
1956

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `paramiko`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 748
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 630
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 543
    - Explicit `Any` variables: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `singledispatch`

### Number of lines
31

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `singledispatch`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 16
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `pyOpenSSL`

### Number of lines
420

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `pyOpenSSL`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 163
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 198
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 120
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `mysqlclient`

### Number of lines
1245

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `mysqlclient`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 24
    - Unannotated parameters: 132
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 83
    - Unannotated returns: 30
    - Explicit `Any` returns: 55
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 972
    - Explicit `Any` variables: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `tzlocal`

### Number of lines
25

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `tzlocal`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `dateparser`

### Number of lines
532

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `dateparser`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 121
    - Unannotated parameters: 127
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 71
    - Unannotated returns: 67
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 137
    - Explicit `Any` variables: 80
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `chardet`

### Number of lines
142

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `chardet`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 7
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 86
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `mock`

### Number of lines
343

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `mock`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 187
    - Unannotated parameters: 6
    - Explicit `Any` parameters: 124
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 82
    - Unannotated returns: 0
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 52
    - Explicit `Any` variables: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `Pygments`

### Number of lines
806

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `Pygments`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 108
    - Unannotated parameters: 168
    - Explicit `Any` parameters: 24
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 96
    - Unannotated returns: 79
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 314
    - Explicit `Any` variables: 193
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `protobuf`

### Number of lines
4864

### Package status: *out of date*
These stubs are out of date. In CI, stubtest tests these stubs against an older version of this package than the latest that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `protobuf`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 725
    - Unannotated parameters: 260
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 477
    - Unannotated returns: 95
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 755
    - Explicit `Any` variables: 126
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `keyboard`

### Number of lines
292

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `keyboard`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 130
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 76
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 51
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `waitress`

### Number of lines
713

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `waitress`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 210
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 44
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 209
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 247
    - Explicit `Any` variables: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `python-gflags`

### Number of lines
309

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `python-gflags`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 186
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 39
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 98
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 19
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `first`

### Number of lines
17

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `first`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `humanfriendly`

### Number of lines
378

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *not strict*
All files are excluded from the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `humanfriendly`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 78
    - Unannotated parameters: 183
    - Explicit `Any` parameters: 22
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 82
    - Unannotated returns: 95
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 75
    - Explicit `Any` variables: 54
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `polib`

### Number of lines
158

### Package status: *up to date*
These stubs should be fairly up to date. In CI, stubtest tests these stubs against the latest version of the package that's available.

### Stubtest settings in CI: *missing stubs ignored*
The `--ignore-missing-stub` stubtest setting is used in CI.

### Pyright settings in CI: *strict*
All files are tested with the stricter pyright settings in CI.

### Statistics on the annotations in typeshed's stubs for `polib`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 62
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 75
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 46
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0

<hr>

## Stats on typeshed's stubs for `stdlib`

### Number of lines
55370

### Package status: *stdlib*
These are the stdlib stubs. Typeshed's stdlib stubs are generally fairly up to date, and tested against all currently supported Python versions in CI.

### Stubtest settings in CI: *error on missing stub*
Objects missing from the stub cause stubtest to emit an error in CI.

### Pyright settings in CI: *strict on some files*
Some files are tested with the stricter pyright settings in CI; some are excluded.

### Statistics on the annotations in typeshed's stubs for `stdlib`
- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 24411
    - Unannotated parameters: 915
    - Explicit `Any` parameters: 2116
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 88
- Returns:
    - Annotated returns: 13282
    - Unannotated returns: 410
    - Explicit `Any` returns: 818
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 18
- Variables:
    - Annotated variables: 8487
    - Explicit `Any` variables: 556
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 101
